Authlib Loginpass
=================

Social connections powered by Authlib_. This library is a part of Authlib project.
It works well with Authlib v0.7+.

.. _Authlib: https://authlib.org/

Useful Links
------------

1. Browser `Source Code <https://github.com/authlib/loginpass>`_.
2. Read `Authlib Documentation <https://docs.authlib.org/>`_.
